﻿using System;
using Wisej.Web;
using System.Globalization;

namespace Wisej.CloseForm
{
	public class MyDateTimePicker : DateTimePicker
	{
		public override string Text
		{
			get
			{
				return base.Text;
			}

			set
			{
				if (base.Text != value)
				{
					if (value == null || value.Length == 0)
					{
						this.Value = DateTime.MinValue;
						OnTextChanged(EventArgs.Empty);
						return;
					}

					DateTime dateTime = DateTime.MinValue;

					if (!ParseEditText(value, out dateTime))
						this.Invalid = true;

					this.Value = dateTime;
				}
			}
		}

		// Parses a string to a valid DateTime using a range
		// of formats, including the custom format, if any.
		private bool ParseEditText(string text, out DateTime value)
		{
			value = DateTime.MinValue;

			if (text != null && text.Length > 0)
			{

				if (this.Format == DateTimePickerFormat.Custom)
				{
					return DateTime.TryParseExact(text, this.CustomFormat, null, DateTimeStyles, out value);
				}
				else
				{
					string[] formats = new[] { "d", "D", "T", "t" };
					return DateTime.TryParse(text, null, DateTimeStyles, out value)
							|| DateTime.TryParseExact(text, formats, null, DateTimeStyles, out value);
				}
			}
			return true;
		}

		private static readonly DateTimeStyles DateTimeStyles =
				DateTimeStyles.AllowInnerWhite | DateTimeStyles.AllowLeadingWhite | DateTimeStyles.AllowWhiteSpaces;

	}
}